@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply chromatic and diatonic transposition to notes
 
-our $VERSION = '0.0400';
+our $VERSION = '0.0500';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
@@ -54,13 +54,23 @@ has verbose => (
 sub transpose {
     my ($self, $offset, $notes) = @_;
 
+    my $named = $notes->[0] =~ /[A-G]/ ? 1 : 0;
+
     my @transposed;
 
     for my $n (@$notes) {
         my ($i, $pitch) = $self->_find_pitch($n);
-        push @transposed, $i == -1
-            ? undef
-            : Music::Note->new($self->_scale->[ $i + $offset ], 'midinum')->format('ISO');
+        if ($i == -1) {
+            push @transposed, undef;
+        }
+        else {
+            if ($named) {
+                push @transposed, Music::Note->new($self->_scale->[ $i + $offset ], 'midinum')->format('ISO');
+            }
+            else {
+                push @transposed, $self->_scale->[ $i + $offset ];
+            }
+        }
     }
     print 'Transposed: ', ddc(\@transposed) if $self->verbose;
 
@@ -70,7 +80,8 @@ sub transpose {
 sub _find_pitch {
     my ($self, $pitch) = @_;
 
-    $pitch = Music::Note->new($pitch, 'ISO')->format('midinum');
+    $pitch = Music::Note->new($pitch, 'ISO')->format('midinum')
+        if $pitch =~ /[A-G]/;
 
     my $i = first_index { $_ == $pitch } @{ $self->_scale };
 
@@ -91,7 +102,7 @@ Music::MelodicDevice::Transposition - Apply chromatic and diatonic transposition
 
 =head1 VERSION
 
-version 0.0400
+version 0.0500
 
 =head1 SYNOPSIS
 
@@ -177,7 +188,7 @@ Gene Boggs <gene@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020 by Gene Boggs.
+This software is copyright (c) 2022 by Gene Boggs.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
